#line 2 "sequence/gcgl.c"

#line 4 "sequence/gcgl.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer gcg_create_buffer
#define yy_delete_buffer gcg_delete_buffer
#define yy_flex_debug gcg_flex_debug
#define yy_init_buffer gcg_init_buffer
#define yy_flush_buffer gcg_flush_buffer
#define yy_load_buffer_state gcg_load_buffer_state
#define yy_switch_to_buffer gcg_switch_to_buffer
#define yyin gcgin
#define yyleng gcgleng
#define yylex gcglex
#define yylineno gcglineno
#define yyout gcgout
#define yyrestart gcgrestart
#define yytext gcgtext
#define yywrap gcgwrap
#define yyalloc gcgalloc
#define yyrealloc gcgrealloc
#define yyfree gcgfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#ifdef _LIBC
#include "namespace.h"
#endif
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/*	$NetBSD: flexint.h,v 1.1.1.1 2009/10/26 00:26:19 christos Exp $	*/

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE gcgrestart(gcgin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int gcgleng;

extern FILE *gcgin, *gcgout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up gcgtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up gcgtext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via gcgrestart()), so that the user can continue scanning by
	 * just pointing gcgin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when gcgtext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int gcgleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow gcgwrap()'s to do buffer switches
 * instead of setting up a fresh gcgin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void gcgrestart (FILE *input_file  );
void gcg_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE gcg_create_buffer (FILE *file,int size  );
void gcg_delete_buffer (YY_BUFFER_STATE b  );
void gcg_flush_buffer (YY_BUFFER_STATE b  );
void gcgpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void gcgpop_buffer_state (void );

static void gcgensure_buffer_stack (void );
static void gcg_load_buffer_state (void );
static void gcg_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER gcg_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE gcg_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE gcg_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE gcg_scan_bytes (yyconst char *bytes,int len  );

void *gcgalloc (yy_size_t  );
void *gcgrealloc (void *,yy_size_t  );
void gcgfree (void *  );

#define yy_new_buffer gcg_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        gcgensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            gcg_create_buffer(gcgin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        gcgensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            gcg_create_buffer(gcgin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define gcgwrap(n) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *gcgin = (FILE *) 0, *gcgout = (FILE *) 0;

typedef int yy_state_type;

extern int gcglineno;

int gcglineno = 1;

extern char *gcgtext;
#define yytext_ptr gcgtext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up gcgtext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	gcgleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 17
#define YY_END_OF_BUFFER 18
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[657] =
    {   0,
        0,    0,    0,    0,    0,    0,   18,   16,   15,   16,
        3,    6,    3,    3,   14,   13,   11,    9,   10,   12,
       11,   14,    0,    3,    3,    3,    3,    8,   11,    9,
       10,   11,    7,    0,    3,    3,    3,    2,    3,    3,
        0,    9,    0,    0,    3,    3,    3,    5,    3,    3,
        9,    0,    3,    3,    3,    3,    4,    3,    9,    0,
        3,    3,    3,    3,    3,    9,    0,    3,    3,    3,
        3,    3,    9,    0,    3,    3,    3,    3,    3,    9,
        0,    3,    3,    3,    3,    3,    9,    0,    3,    3,
        3,    3,    3,    9,    0,    3,    3,    3,    3,    3,

        9,    0,    3,    3,    3,    3,    3,    9,    0,    3,
        3,    3,    3,    3,    9,    0,    3,    3,    3,    3,
        3,    9,    0,    3,    3,    3,    3,    3,    9,    0,
        3,    3,    3,    3,    3,    3,    9,    1,    3,    3,
        3,    3,    1,    3,    3,    9,    3,    3,    3,    3,
        1,    3,    3,    9,    3,    3,    3,    3,    1,    3,
        3,    9,    3,    3,    3,    3,    1,    3,    3,    9,
        3,    3,    3,    3,    1,    3,    3,    9,    3,    3,
        3,    3,    1,    3,    3,    9,    3,    3,    3,    3,
        1,    3,    3,    9,    3,    3,    3,    3,    1,    3,

        3,    9,    3,    3,    3,    3,    1,    3,    3,    9,
        3,    3,    3,    3,    1,    3,    3,    9,    3,    3,
        3,    3,    1,    3,    3,    9,    3,    3,    3,    3,
        1,    3,    3,    9,    3,    3,    3,    3,    1,    3,
        3,    9,    3,    3,    3,    3,    1,    3,    3,    9,
        3,    3,    3,    3,    1,    3,    3,    9,    3,    3,
        3,    3,    1,    3,    3,    9,    3,    3,    3,    3,
        1,    3,    3,    9,    3,    3,    3,    3,    1,    3,
        3,    9,    3,    3,    3,    3,    1,    3,    3,    9,
        3,    3,    3,    3,    1,    3,    3,    9,    3,    3,

        3,    3,    1,    3,    3,    9,    3,    3,    3,    3,
        1,    3,    3,    9,    3,    3,    3,    3,    1,    3,
        3,    9,    3,    3,    3,    3,    1,    3,    3,    9,
        3,    3,    3,    3,    1,    3,    3,    9,    3,    3,
        3,    3,    1,    3,    3,    9,    3,    3,    3,    3,
        1,    3,    3,    9,    3,    3,    3,    3,    1,    3,
        3,    9,    3,    3,    3,    3,    1,    3,    3,    9,
        3,    3,    3,    3,    1,    3,    3,    9,    3,    3,
        3,    3,    1,    3,    3,    9,    3,    3,    3,    3,
        1,    3,    3,    9,    3,    3,    3,    3,    1,    3,

        3,    9,    3,    3,    3,    3,    1,    3,    3,    9,
        3,    3,    3,    3,    1,    3,    3,    9,    3,    3,
        3,    3,    1,    3,    3,    9,    3,    3,    3,    3,
        1,    3,    3,    9,    3,    3,    3,    3,    1,    3,
        3,    9,    3,    3,    3,    3,    1,    3,    3,    9,
        3,    3,    3,    3,    1,    3,    3,    9,    3,    3,
        3,    3,    1,    3,    3,    9,    3,    3,    3,    3,
        1,    3,    3,    9,    3,    3,    3,    3,    1,    3,
        3,    9,    3,    3,    3,    3,    1,    3,    3,    9,
        3,    3,    3,    3,    1,    3,    3,    9,    3,    3,

        3,    3,    1,    3,    3,    9,    3,    3,    3,    3,
        1,    3,    3,    9,    3,    3,    3,    3,    1,    3,
        3,    9,    3,    3,    3,    3,    1,    3,    3,    9,
        3,    3,    3,    3,    1,    3,    3,    9,    3,    3,
        3,    3,    1,    3,    3,    9,    3,    3,    3,    3,
        1,    3,    3,    9,    3,    3,    3,    3,    1,    3,
        3,    9,    3,    3,    3,    3,    1,    3,    3,    9,
        3,    3,    3,    3,    1,    3,    3,    9,    3,    3,
        3,    3,    1,    3,    3,    9,    3,    3,    3,    3,
        1,    3,    3,    9,    3,    3,    3,    3,    1,    3,

        3,    9,    3,    3,    3,    3,    1,    3,    3,    9,
        3,    3,    3,    3,    1,    3,    3,    9,    3,    3,
        3,    3,    1,    3,    3,    9,    3,    3,    3,    3,
        1,    3,    3,    9,    3,    3,    3,    3,    1,    3,
        3,    9,    3,    3,    3,    3,    1,    3,    3,    9,
        0,    0,    0,    0,    0,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    3,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    1,    1,    6,    7,    1,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    1,    1,    1,
        1,    1,    1,    1,    9,   10,   11,   10,   12,   10,
       10,   10,   10,   10,   10,   10,   10,   13,   10,   10,
       14,   10,   15,   10,   16,   10,   10,   10,   10,   10,
        1,    1,    1,    1,   17,    1,   10,   10,   10,   10,

       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[18] =
    {   0,
        1,    2,    1,    1,    3,    3,    1,    1,    3,    3,
        3,    3,    3,    3,    3,    3,    1
    } ;

static yyconst flex_int16_t yy_base[817] =
    {   0,
     1282,    0,    1,    7,   14,   30, 1283, 1285, 1285, 1278,
     1274, 1285, 1273,    3, 1285, 1285,    3,    0, 1271, 1285,
       33, 1274,   29, 1270, 1269,   41,   42, 1285,   10,    0,
     1267, 1271, 1285, 1264, 1265, 1264,   54, 1285,   38,   30,
       44,    0,    0, 1253, 1262, 1261,   60, 1285,   51,   43,
        0, 1252, 1259, 1258,   66,   52, 1285,   57,    0, 1252,
     1256, 1255,   72,   63,   59,    0, 1247, 1253, 1252,   78,
       75,   69,    0, 1242, 1250, 1249,   84,   82,   81,    0,
     1243, 1247, 1246,   96,   88,   89,    0, 1239, 1244, 1243,
      102,  100,   87,    0, 1238, 1241, 1240,  108,  106,  105,

        0, 1234, 1238, 1237,  115,  112,  113,    0, 1240, 1235,
     1234,  124,  121,  126,    0, 1232, 1232, 1231,  132,  130,
       85,    0,  133, 1230, 1229,  140,  142,  138,    0, 1227,
     1227, 1226,  148,  146,  149,  151,    0, 1224, 1224, 1223,
      158,  160,  156,  161,  163,    0, 1222, 1221,  170,  172,
      168,  173,  175,    0, 1220, 1219,  182,  184,  180,  185,
      187,    0, 1218, 1217,  194,  196,  192,  197,  199,    0,
     1216, 1215,  206,  208,  204,  209,  211,    0, 1214, 1213,
      218,  220,  216,  221,  223,    0, 1212, 1211,  230,  232,
      228,  233,  235,    0, 1210, 1209,  242,  244,  240,  245,

      247,    0, 1208, 1207,  254,  256,  252,  257,  259,    0,
     1206, 1205,  266,  268,  264,  269,  271,    0, 1204, 1203,
      278,  280,  276,  281,  283,    0, 1202, 1201,  290,  292,
      288,  293,  295,    0, 1200, 1199,  302,  304,  300,  305,
      307,    0, 1198, 1197,  314,  316,  312,  317,  319,    0,
     1196, 1195,  326,  328,  324,  329,  331,    0, 1194, 1193,
      338,  340,  336,  341,  343,    0, 1192, 1191,  350,  352,
      348,  353,  355,    0, 1190, 1189,  362,  364,  360,  365,
      367,    0, 1188, 1187,  374,  376,  372,  377,  379,    0,
     1186, 1185,  386,  388,  384,  389,  391,    0, 1184, 1183,

      398,  400,  396,  401,  403,    0, 1182, 1181,  410,  412,
      408,  413,  415,    0, 1180, 1179,  422,  424,  420,  425,
      427,    0, 1178, 1177,  434,  436,  432,  437,  439,    0,
     1176, 1175,  446,  448,  444,  449,  451,    0, 1174, 1173,
      458,  460,  456,  461,  463,    0, 1172, 1171,  470,  472,
      468,  473,  475,    0, 1170, 1169,  482,  484,  480,  485,
      487,    0, 1168, 1166,  494,  496,  492,  497,  499,    0,
     1163, 1160,  506,  508,  504,  509,  511,    0, 1157, 1154,
      518,  520,  516,  521,  523,    0, 1151, 1148,  530,  532,
      528,  533,  535,    0, 1145, 1142,  542,  544,  540,  545,

      547,    0, 1139, 1136,  554,  556,  552,  557,  559,    0,
     1133, 1130,  566,  568,  564,  569,  571,    0, 1127, 1124,
      578,  580,  576,  581,  583,    0, 1121, 1118,  590,  592,
      588,  593,  595,    0, 1115, 1112,  602,  604,  600,  605,
      607,    0, 1109, 1106,  614,  616,  612,  617,  619,    0,
     1103, 1100,  626,  628,  624,  629,  631,    0, 1097, 1094,
      638,  640,  636,  641,  643,    0, 1091, 1088,  650,  652,
      648,  653,  655,    0, 1085, 1082,  662,  664,  660,  665,
      667,    0, 1079, 1076,  674,  676,  672,  677,  679,    0,
     1073, 1070,  686,  688,  684,  689,  691,    0, 1067, 1064,

      698,  700,  696,  701,  703,    0, 1061, 1058,  710,  712,
      708,  713,  715,    0, 1055, 1052,  722,  724,  720,  725,
      727,    0, 1049, 1046,  734,  736,  732,  737,  739,    0,
     1043, 1040,  746,  748,  744,  749,  751,    0, 1037, 1034,
      758,  760,  756,  761,  763,    0, 1031, 1028,  770,  772,
      768,  773,  775,    0, 1025, 1022,  782,  784,  780,  785,
      787,    0, 1019, 1016,  794,  796,  792,  797,  799,    0,
     1013, 1010,  806,  808,  804,  809,  811,    0, 1007, 1004,
      818,  820,  816,  821,  823,    0, 1001,  998,  830,  832,
      828,  833,  835,    0,  995,  992,  842,  844,  840,  845,

      847,    0,  989,  986,  854,  856,  852,  857,  859,    0,
      983,  980,  866,  868,  864,  869,  871,    0,  977,  974,
      878,  880,  876,  881,  883,    0,  971,  968,  890,  892,
      888,  893,  895,    0,  965,  962,  902,  904,  900,  905,
      907,    0,  959,  956,  914,  916,  912,  917,  919, 1285,
      953,  950,  952,  921,  928, 1285,  931,  934,  937,  948,
      940,  945,  943,  942,  946,  939,  949,  936,  952,  919,
      955,  907,  958,  895,  961,  883,  964,  871,  967,  859,
      970,  847,  973,  835,  976,  823,  979,  811,  982,  799,
      985,  787,  988,  775,  991,  763,  994,  751,  997,  739,

     1000,  727, 1003,  715, 1006,  703, 1009,  691, 1012,  679,
     1015,  667, 1018,  655, 1021,  643, 1024,  631, 1027,  619,
     1030,  607, 1033,  595, 1036,  583, 1039,  571, 1042,  559,
     1045,  547, 1048,  535, 1051,  523, 1054,  511, 1057,  499,
     1060,  487, 1063,  475, 1066,  463, 1069,  451, 1072,  439,
     1075,  427, 1078,  415, 1081,  403, 1084,  391, 1087,  379,
     1090,  367, 1093,  355, 1096,  343, 1099,  331, 1102,  319,
     1105,  307, 1108,  295, 1111,  283, 1114,  271, 1117,  259,
     1120,  247, 1123,  235, 1126,  223, 1129,  211, 1132,  199,
     1135,  187, 1138,  175, 1141,  163, 1144,  151, 1147,  149,

     1150,  135, 1153,  133, 1156,  127, 1159,  121, 1162,  118,
     1165,  103, 1168,   75, 1171,   49
    } ;

static yyconst flex_int16_t yy_def[817] =
    {   0,
      657,  657,  658,  658,  656,    5,  656,  656,  656,  656,
      659,  656,  659,  659,  656,  656,  656,  660,  656,  656,
      656,  656,  656,  661,  661,  661,  661,  656,  656,  662,
      656,   21,  656,  656,  663,  663,  663,  656,  663,  663,
      656,  664,   32,  656,  665,  665,  665,  656,  665,  665,
      666,  656,  667,  667,  667,  667,  656,  667,  668,  656,
      669,  669,  669,  669,  669,  670,  656,  671,  671,  671,
      671,  671,  672,  656,  673,  673,  673,  673,  673,  674,
      656,  675,  675,  675,  675,  675,  676,  656,  677,  677,
      677,  677,  677,  678,  656,  679,  679,  679,  679,  679,

      680,  656,  681,  681,  681,  681,  681,  682,  656,  683,
      683,  683,  683,  683,  684,  656,  685,  685,  685,  685,
      685,  686,  656,  687,  687,  687,  687,  687,  688,  656,
      689,  689,  689,  689,  689,  689,  690,  656,  691,  691,
      691,  691,  691,  691,  691,  692,  693,  693,  693,  693,
      693,  693,  693,  694,  695,  695,  695,  695,  695,  695,
      695,  696,  697,  697,  697,  697,  697,  697,  697,  698,
      699,  699,  699,  699,  699,  699,  699,  700,  701,  701,
      701,  701,  701,  701,  701,  702,  703,  703,  703,  703,
      703,  703,  703,  704,  705,  705,  705,  705,  705,  705,

      705,  706,  707,  707,  707,  707,  707,  707,  707,  708,
      709,  709,  709,  709,  709,  709,  709,  710,  711,  711,
      711,  711,  711,  711,  711,  712,  713,  713,  713,  713,
      713,  713,  713,  714,  715,  715,  715,  715,  715,  715,
      715,  716,  717,  717,  717,  717,  717,  717,  717,  718,
      719,  719,  719,  719,  719,  719,  719,  720,  721,  721,
      721,  721,  721,  721,  721,  722,  723,  723,  723,  723,
      723,  723,  723,  724,  725,  725,  725,  725,  725,  725,
      725,  726,  727,  727,  727,  727,  727,  727,  727,  728,
      729,  729,  729,  729,  729,  729,  729,  730,  731,  731,

      731,  731,  731,  731,  731,  732,  733,  733,  733,  733,
      733,  733,  733,  734,  735,  735,  735,  735,  735,  735,
      735,  736,  737,  737,  737,  737,  737,  737,  737,  738,
      739,  739,  739,  739,  739,  739,  739,  740,  741,  741,
      741,  741,  741,  741,  741,  742,  743,  743,  743,  743,
      743,  743,  743,  744,  745,  745,  745,  745,  745,  745,
      745,  746,  747,  747,  747,  747,  747,  747,  747,  748,
      749,  749,  749,  749,  749,  749,  749,  750,  751,  751,
      751,  751,  751,  751,  751,  752,  753,  753,  753,  753,
      753,  753,  753,  754,  755,  755,  755,  755,  755,  755,

      755,  756,  757,  757,  757,  757,  757,  757,  757,  758,
      759,  759,  759,  759,  759,  759,  759,  760,  761,  761,
      761,  761,  761,  761,  761,  762,  763,  763,  763,  763,
      763,  763,  763,  764,  765,  765,  765,  765,  765,  765,
      765,  766,  767,  767,  767,  767,  767,  767,  767,  768,
      769,  769,  769,  769,  769,  769,  769,  770,  771,  771,
      771,  771,  771,  771,  771,  772,  773,  773,  773,  773,
      773,  773,  773,  774,  775,  775,  775,  775,  775,  775,
      775,  776,  777,  777,  777,  777,  777,  777,  777,  778,
      779,  779,  779,  779,  779,  779,  779,  780,  781,  781,

      781,  781,  781,  781,  781,  782,  783,  783,  783,  783,
      783,  783,  783,  784,  785,  785,  785,  785,  785,  785,
      785,  786,  787,  787,  787,  787,  787,  787,  787,  788,
      789,  789,  789,  789,  789,  789,  789,  790,  791,  791,
      791,  791,  791,  791,  791,  792,  793,  793,  793,  793,
      793,  793,  793,  794,  795,  795,  795,  795,  795,  795,
      795,  796,  797,  797,  797,  797,  797,  797,  797,  798,
      799,  799,  799,  799,  799,  799,  799,  800,  801,  801,
      801,  801,  801,  801,  801,  802,  803,  803,  803,  803,
      803,  803,  803,  804,  805,  805,  805,  805,  805,  805,

      805,  806,  807,  807,  807,  807,  807,  807,  807,  808,
      809,  809,  809,  809,  809,  809,  809,  810,  811,  811,
      811,  811,  811,  811,  811,  812,  813,  813,  813,  813,
      813,  813,  813,  814,  815,  815,  815,  815,  815,  815,
      815,  816,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  645,  656,  656,  656,    0,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,

      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,

      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656
    } ;

static yyconst flex_int16_t yy_nxt[1303] =
    {   0,
      656,    9,   12,   10,   28,   29,   27,   13,   12,   25,
       14,   28,   41,   13,   15,   16,   17,   15,   18,   18,
       15,   19,   18,   18,   18,   18,   18,   18,   18,   18,
       15,   20,   21,   22,   28,   32,   46,   34,   50,   38,
       33,   34,   38,   39,   46,   28,   41,   37,   36,   54,
       40,  650,   57,   57,   40,   48,   49,   54,   62,   58,
       47,   48,   56,   62,   57,   69,   55,   48,   64,   69,
       72,   65,   63,   48,   71,   76,   57,  642,   70,   48,
       78,   76,   79,   57,   77,   48,   85,   83,   83,   57,
       84,  125,  128,   97,   90,   90,   86,   48,   92,  100,

       93,   57,   91,   48,   99,  634,   97,   57,   98,   48,
      106,  104,  104,   57,  105,  107,   48,  113,  111,  111,
      626,  112,   57,  618,  114,   48,  120,  118,  121,  610,
      119,   57,  118,   48,  127,  602,  125,  594,  126,  130,
      123,   48,  134,   57,  135,  136,  133,   57,  132,   48,
      142,  586,  140,  578,  141,  141,  143,  144,  145,   48,
      150,   57,  148,  151,  149,  570,  148,  149,  151,  152,
      153,   48,  158,   57,  156,  159,  157,  562,  156,  157,
      159,  160,  161,   48,  166,   57,  164,  167,  165,  554,
      164,  165,  167,  168,  169,   48,  174,   57,  172,  175,

      173,  546,  172,  173,  175,  176,  177,   48,  182,   57,
      180,  183,  181,  538,  180,  181,  183,  184,  185,   48,
      190,   57,  188,  191,  189,  530,  188,  189,  191,  192,
      193,   48,  198,   57,  196,  199,  197,  522,  196,  197,
      199,  200,  201,   48,  206,   57,  204,  207,  205,  514,
      204,  205,  207,  208,  209,   48,  214,   57,  212,  215,
      213,  506,  212,  213,  215,  216,  217,   48,  222,   57,
      220,  223,  221,  498,  220,  221,  223,  224,  225,   48,
      230,   57,  228,  231,  229,  490,  228,  229,  231,  232,
      233,   48,  238,   57,  236,  239,  237,  482,  236,  237,

      239,  240,  241,   48,  246,   57,  244,  247,  245,  474,
      244,  245,  247,  248,  249,   48,  254,   57,  252,  255,
      253,  466,  252,  253,  255,  256,  257,   48,  262,   57,
      260,  263,  261,  458,  260,  261,  263,  264,  265,   48,
      270,   57,  268,  271,  269,  450,  268,  269,  271,  272,
      273,   48,  278,   57,  276,  279,  277,  442,  276,  277,
      279,  280,  281,   48,  286,   57,  284,  287,  285,  434,
      284,  285,  287,  288,  289,   48,  294,   57,  292,  295,
      293,  426,  292,  293,  295,  296,  297,   48,  302,   57,
      300,  303,  301,  418,  300,  301,  303,  304,  305,   48,

      310,   57,  308,  311,  309,  410,  308,  309,  311,  312,
      313,   48,  318,   57,  316,  319,  317,  402,  316,  317,
      319,  320,  321,   48,  326,   57,  324,  327,  325,  394,
      324,  325,  327,  328,  329,   48,  334,   57,  332,  335,
      333,  386,  332,  333,  335,  336,  337,   48,  342,   57,
      340,  343,  341,  378,  340,  341,  343,  344,  345,   48,
      350,   57,  348,  351,  349,  370,  348,  349,  351,  352,
      353,   48,  358,   57,  356,  359,  357,  362,  356,  357,
      359,  360,  361,   48,  366,   57,  364,  367,  365,  354,
      364,  365,  367,  368,  369,   48,  374,   57,  372,  375,

      373,  346,  372,  373,  375,  376,  377,   48,  382,   57,
      380,  383,  381,  338,  380,  381,  383,  384,  385,   48,
      390,   57,  388,  391,  389,  330,  388,  389,  391,  392,
      393,   48,  398,   57,  396,  399,  397,  322,  396,  397,
      399,  400,  401,   48,  406,   57,  404,  407,  405,  314,
      404,  405,  407,  408,  409,   48,  414,   57,  412,  415,
      413,  306,  412,  413,  415,  416,  417,   48,  422,   57,
      420,  423,  421,  298,  420,  421,  423,  424,  425,   48,
      430,   57,  428,  431,  429,  290,  428,  429,  431,  432,
      433,   48,  438,   57,  436,  439,  437,  282,  436,  437,

      439,  440,  441,   48,  446,   57,  444,  447,  445,  274,
      444,  445,  447,  448,  449,   48,  454,   57,  452,  455,
      453,  266,  452,  453,  455,  456,  457,   48,  462,   57,
      460,  463,  461,  258,  460,  461,  463,  464,  465,   48,
      470,   57,  468,  471,  469,  250,  468,  469,  471,  472,
      473,   48,  478,   57,  476,  479,  477,  242,  476,  477,
      479,  480,  481,   48,  486,   57,  484,  487,  485,  234,
      484,  485,  487,  488,  489,   48,  494,   57,  492,  495,
      493,  226,  492,  493,  495,  496,  497,   48,  502,   57,
      500,  503,  501,  218,  500,  501,  503,  504,  505,   48,

      510,   57,  508,  511,  509,  210,  508,  509,  511,  512,
      513,   48,  518,   57,  516,  519,  517,  202,  516,  517,
      519,  520,  521,   48,  526,   57,  524,  527,  525,  194,
      524,  525,  527,  528,  529,   48,  534,   57,  532,  535,
      533,  186,  532,  533,  535,  536,  537,   48,  542,   57,
      540,  543,  541,  178,  540,  541,  543,  544,  545,   48,
      550,   57,  548,  551,  549,  170,  548,  549,  551,  552,
      553,   48,  558,   57,  556,  559,  557,  162,  556,  557,
      559,  560,  561,   48,  566,   57,  564,  567,  565,  154,
      564,  565,  567,  568,  569,   48,  574,   57,  572,  575,

      573,  146,  572,  573,  575,  576,  577,   48,  582,   57,
      580,  583,  581,  137,  580,  581,  583,  584,  585,   48,
      590,   57,  588,  591,  589,  129,  588,  589,  591,  592,
      593,   48,  598,   57,  596,  599,  597,  122,  596,  597,
      599,  600,  601,   48,  606,   57,  604,  607,  605,  115,
      604,  605,  607,  608,  609,   48,  614,   57,  612,  615,
      613,  108,  612,  613,  615,  616,  617,   48,  622,   57,
      620,  623,  621,  101,  620,  621,  623,  624,  625,   48,
      630,   57,  628,  631,  629,   94,  628,  629,  631,  632,
      633,   48,  638,   57,  636,  639,  637,   87,  636,  637,

      639,  640,  641,   48,  646,   57,  644,  647,  645,   80,
      644,  645,  647,  648,  649,   48,  653,   57,  651,  138,
      652,   73,  651,  652,  138,  654,  123,  655,  138,   48,
      653,    8,    8,    8,   11,   11,   11,   24,   66,   24,
       35,   59,   35,   45,   51,   45,   53,   42,   53,   61,
       30,   61,   68,   57,   68,   75,  655,   75,   82,  655,
       82,   89,  652,   89,   96,  651,   96,  103,  645,  103,
      110,  644,  110,  117,  637,  117,  124,  636,  124,  131,
      629,  131,  139,  628,  139,  147,  621,  147,  155,  620,
      155,  163,  613,  163,  171,  612,  171,  179,  605,  179,

      187,  604,  187,  195,  597,  195,  203,  596,  203,  211,
      589,  211,  219,  588,  219,  227,  581,  227,  235,  580,
      235,  243,  573,  243,  251,  572,  251,  259,  565,  259,
      267,  564,  267,  275,  557,  275,  283,  556,  283,  291,
      549,  291,  299,  548,  299,  307,  541,  307,  315,  540,
      315,  323,  533,  323,  331,  532,  331,  339,  525,  339,
      347,  524,  347,  355,  517,  355,  363,  516,  363,  371,
      509,  371,  379,  508,  379,  387,  501,  387,  395,  500,
      395,  403,  493,  403,  411,  492,  411,  419,  485,  419,
      427,  484,  427,  435,  477,  435,  443,  476,  443,  451,

      469,  451,  459,  468,  459,  467,  461,  467,  475,  460,
      475,  483,  453,  483,  491,  452,  491,  499,  445,  499,
      507,  444,  507,  515,  437,  515,  523,  436,  523,  531,
      429,  531,  539,  428,  539,  547,  421,  547,  555,  420,
      555,  563,  413,  563,  571,  412,  571,  579,  405,  579,
      587,  404,  587,  595,  397,  595,  603,  396,  603,  611,
      389,  611,  619,  388,  619,  627,  381,  627,  635,  380,
      635,  643,  373,  643,  372,  365,  364,  357,  356,  349,
      348,  341,  340,  333,  332,  325,  324,  317,  316,  309,
      308,  301,  300,  293,  292,  285,  284,  277,  276,  269,

      268,  261,  260,  253,  252,  245,  244,  237,  236,  229,
      228,  221,  220,  213,  212,  205,  204,  197,  196,  189,
      188,  181,  180,  173,  172,  165,  164,  157,  156,  149,
      148,  138,  141,  140,  138,  133,  132,  126,  125,  123,
      119,  118,  116,  112,  111,  109,  105,  104,  102,   98,
       97,   95,   91,   90,   88,   84,   83,   81,   77,   76,
       74,   70,   69,   67,   63,   62,   60,   55,   54,   52,
       47,   46,   44,   43,   31,   37,   36,   23,   31,   26,
       25,   23,  656,    9,    7,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,

      656,  656
    } ;

static yyconst flex_int16_t yy_chk[1303] =
    {   0,
        0,    2,    3,    2,   17,   17,   14,    3,    4,   14,
        4,   29,   29,    4,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    6,    6,    6,   21,   21,   40,   23,   40,   39,
       21,   23,   26,   26,   39,   41,   41,   26,   27,   50,
       27,  816,   49,   56,   27,   37,   37,   49,   56,   50,
       37,   47,   47,   58,   64,   65,   47,   55,   55,   64,
       65,   58,   55,   63,   63,   72,   71,  814,   63,   70,
       70,   71,   72,   78,   70,   77,   77,   79,   78,   85,
       77,  121,  121,   93,   85,   86,   79,   84,   84,   93,

       86,   92,   84,   91,   91,  812,   92,   99,   91,   98,
       98,  100,   99,  106,   98,  100,  105,  105,  106,  107,
      810,  105,  113,  808,  107,  112,  112,  113,  114,  806,
      112,  120,  114,  119,  119,  804,  120,  802,  119,  123,
      123,  126,  126,  127,  128,  128,  126,  134,  127,  133,
      133,  800,  134,  798,  133,  135,  135,  136,  136,  141,
      141,  142,  143,  143,  141,  796,  142,  144,  144,  145,
      145,  149,  149,  150,  151,  151,  149,  794,  150,  152,
      152,  153,  153,  157,  157,  158,  159,  159,  157,  792,
      158,  160,  160,  161,  161,  165,  165,  166,  167,  167,

      165,  790,  166,  168,  168,  169,  169,  173,  173,  174,
      175,  175,  173,  788,  174,  176,  176,  177,  177,  181,
      181,  182,  183,  183,  181,  786,  182,  184,  184,  185,
      185,  189,  189,  190,  191,  191,  189,  784,  190,  192,
      192,  193,  193,  197,  197,  198,  199,  199,  197,  782,
      198,  200,  200,  201,  201,  205,  205,  206,  207,  207,
      205,  780,  206,  208,  208,  209,  209,  213,  213,  214,
      215,  215,  213,  778,  214,  216,  216,  217,  217,  221,
      221,  222,  223,  223,  221,  776,  222,  224,  224,  225,
      225,  229,  229,  230,  231,  231,  229,  774,  230,  232,

      232,  233,  233,  237,  237,  238,  239,  239,  237,  772,
      238,  240,  240,  241,  241,  245,  245,  246,  247,  247,
      245,  770,  246,  248,  248,  249,  249,  253,  253,  254,
      255,  255,  253,  768,  254,  256,  256,  257,  257,  261,
      261,  262,  263,  263,  261,  766,  262,  264,  264,  265,
      265,  269,  269,  270,  271,  271,  269,  764,  270,  272,
      272,  273,  273,  277,  277,  278,  279,  279,  277,  762,
      278,  280,  280,  281,  281,  285,  285,  286,  287,  287,
      285,  760,  286,  288,  288,  289,  289,  293,  293,  294,
      295,  295,  293,  758,  294,  296,  296,  297,  297,  301,

      301,  302,  303,  303,  301,  756,  302,  304,  304,  305,
      305,  309,  309,  310,  311,  311,  309,  754,  310,  312,
      312,  313,  313,  317,  317,  318,  319,  319,  317,  752,
      318,  320,  320,  321,  321,  325,  325,  326,  327,  327,
      325,  750,  326,  328,  328,  329,  329,  333,  333,  334,
      335,  335,  333,  748,  334,  336,  336,  337,  337,  341,
      341,  342,  343,  343,  341,  746,  342,  344,  344,  345,
      345,  349,  349,  350,  351,  351,  349,  744,  350,  352,
      352,  353,  353,  357,  357,  358,  359,  359,  357,  742,
      358,  360,  360,  361,  361,  365,  365,  366,  367,  367,

      365,  740,  366,  368,  368,  369,  369,  373,  373,  374,
      375,  375,  373,  738,  374,  376,  376,  377,  377,  381,
      381,  382,  383,  383,  381,  736,  382,  384,  384,  385,
      385,  389,  389,  390,  391,  391,  389,  734,  390,  392,
      392,  393,  393,  397,  397,  398,  399,  399,  397,  732,
      398,  400,  400,  401,  401,  405,  405,  406,  407,  407,
      405,  730,  406,  408,  408,  409,  409,  413,  413,  414,
      415,  415,  413,  728,  414,  416,  416,  417,  417,  421,
      421,  422,  423,  423,  421,  726,  422,  424,  424,  425,
      425,  429,  429,  430,  431,  431,  429,  724,  430,  432,

      432,  433,  433,  437,  437,  438,  439,  439,  437,  722,
      438,  440,  440,  441,  441,  445,  445,  446,  447,  447,
      445,  720,  446,  448,  448,  449,  449,  453,  453,  454,
      455,  455,  453,  718,  454,  456,  456,  457,  457,  461,
      461,  462,  463,  463,  461,  716,  462,  464,  464,  465,
      465,  469,  469,  470,  471,  471,  469,  714,  470,  472,
      472,  473,  473,  477,  477,  478,  479,  479,  477,  712,
      478,  480,  480,  481,  481,  485,  485,  486,  487,  487,
      485,  710,  486,  488,  488,  489,  489,  493,  493,  494,
      495,  495,  493,  708,  494,  496,  496,  497,  497,  501,

      501,  502,  503,  503,  501,  706,  502,  504,  504,  505,
      505,  509,  509,  510,  511,  511,  509,  704,  510,  512,
      512,  513,  513,  517,  517,  518,  519,  519,  517,  702,
      518,  520,  520,  521,  521,  525,  525,  526,  527,  527,
      525,  700,  526,  528,  528,  529,  529,  533,  533,  534,
      535,  535,  533,  698,  534,  536,  536,  537,  537,  541,
      541,  542,  543,  543,  541,  696,  542,  544,  544,  545,
      545,  549,  549,  550,  551,  551,  549,  694,  550,  552,
      552,  553,  553,  557,  557,  558,  559,  559,  557,  692,
      558,  560,  560,  561,  561,  565,  565,  566,  567,  567,

      565,  690,  566,  568,  568,  569,  569,  573,  573,  574,
      575,  575,  573,  688,  574,  576,  576,  577,  577,  581,
      581,  582,  583,  583,  581,  686,  582,  584,  584,  585,
      585,  589,  589,  590,  591,  591,  589,  684,  590,  592,
      592,  593,  593,  597,  597,  598,  599,  599,  597,  682,
      598,  600,  600,  601,  601,  605,  605,  606,  607,  607,
      605,  680,  606,  608,  608,  609,  609,  613,  613,  614,
      615,  615,  613,  678,  614,  616,  616,  617,  617,  621,
      621,  622,  623,  623,  621,  676,  622,  624,  624,  625,
      625,  629,  629,  630,  631,  631,  629,  674,  630,  632,

      632,  633,  633,  637,  637,  638,  639,  639,  637,  672,
      638,  640,  640,  641,  641,  645,  645,  646,  647,  647,
      645,  670,  646,  648,  648,  649,  649,  654,  654,  655,
      655,  657,  657,  657,  658,  658,  658,  659,  668,  659,
      661,  666,  661,  663,  664,  663,  665,  662,  665,  667,
      660,  667,  669,  653,  669,  671,  652,  671,  673,  651,
      673,  675,  644,  675,  677,  643,  677,  679,  636,  679,
      681,  635,  681,  683,  628,  683,  685,  627,  685,  687,
      620,  687,  689,  619,  689,  691,  612,  691,  693,  611,
      693,  695,  604,  695,  697,  603,  697,  699,  596,  699,

      701,  595,  701,  703,  588,  703,  705,  587,  705,  707,
      580,  707,  709,  579,  709,  711,  572,  711,  713,  571,
      713,  715,  564,  715,  717,  563,  717,  719,  556,  719,
      721,  555,  721,  723,  548,  723,  725,  547,  725,  727,
      540,  727,  729,  539,  729,  731,  532,  731,  733,  531,
      733,  735,  524,  735,  737,  523,  737,  739,  516,  739,
      741,  515,  741,  743,  508,  743,  745,  507,  745,  747,
      500,  747,  749,  499,  749,  751,  492,  751,  753,  491,
      753,  755,  484,  755,  757,  483,  757,  759,  476,  759,
      761,  475,  761,  763,  468,  763,  765,  467,  765,  767,

      460,  767,  769,  459,  769,  771,  452,  771,  773,  451,
      773,  775,  444,  775,  777,  443,  777,  779,  436,  779,
      781,  435,  781,  783,  428,  783,  785,  427,  785,  787,
      420,  787,  789,  419,  789,  791,  412,  791,  793,  411,
      793,  795,  404,  795,  797,  403,  797,  799,  396,  799,
      801,  395,  801,  803,  388,  803,  805,  387,  805,  807,
      380,  807,  809,  379,  809,  811,  372,  811,  813,  371,
      813,  815,  364,  815,  363,  356,  355,  348,  347,  340,
      339,  332,  331,  324,  323,  316,  315,  308,  307,  300,
      299,  292,  291,  284,  283,  276,  275,  268,  267,  260,

      259,  252,  251,  244,  243,  236,  235,  228,  227,  220,
      219,  212,  211,  204,  203,  196,  195,  188,  187,  180,
      179,  172,  171,  164,  163,  156,  155,  148,  147,  140,
      139,  138,  132,  131,  130,  125,  124,  118,  117,  116,
      111,  110,  109,  104,  103,  102,   97,   96,   95,   90,
       89,   88,   83,   82,   81,   76,   75,   74,   69,   68,
       67,   62,   61,   60,   54,   53,   52,   46,   45,   44,
       36,   35,   34,   32,   31,   25,   24,   22,   19,   13,
       11,   10,    7,    1,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,

      656,  656
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int gcg_flex_debug;
int gcg_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *gcgtext;
#line 1 "sequence/gcgl.l"
/* gcgl.l - GCG sequence lexer */
#line 4 "sequence/gcgl.l"
#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#ifdef STDC_HEADERS
# include <stdlib.h>
# include <string.h>
#endif

#include "sequence/gcgy.h"

static int init = 0;
#define YY_NO_INPUT 1

#line 1032 "sequence/gcgl.c"

#define INITIAL 0
#define HEAD 1
#define SEQS 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int gcglex_destroy (void );

int gcgget_debug (void );

void gcgset_debug (int debug_flag  );

YY_EXTRA_TYPE gcgget_extra (void );

void gcgset_extra (YY_EXTRA_TYPE user_defined  );

FILE *gcgget_in (void );

void gcgset_in  (FILE * _in_str  );

FILE *gcgget_out (void );

void gcgset_out  (FILE * _out_str  );

int gcgget_leng (void );

char *gcgget_text (void );

int gcgget_lineno (void );

void gcgset_lineno (int _line_number  );

YYSTYPE * gcgget_lval (void );

void gcgset_lval (YYSTYPE * yylval_param  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int gcgwrap (void );
#else
extern int gcgwrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( gcgtext, gcgleng, 1, gcgout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( gcgin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( gcgin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, gcgin))==0 && ferror(gcgin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(gcgin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int gcglex \
               (YYSTYPE * yylval_param );

#define YY_DECL int gcglex \
               (YYSTYPE * yylval_param )
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after gcgtext and gcgleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( gcgleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(gcgtext[gcgleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
        YYSTYPE * yylval;
    
#line 38 "sequence/gcgl.l"



if (init == 0) { init = 1; BEGIN HEAD; } /* FIXME: Not thread safe !!! */


#line 1236 "sequence/gcgl.c"

    yylval = yylval_param;

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! gcgin )
			gcgin = stdin;

		if ( ! gcgout )
			gcgout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			gcgensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				gcg_create_buffer(gcgin,YY_BUF_SIZE );
		}

		gcg_load_buffer_state( );
		}

	while (/*CONSTCOND*/ 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of gcgtext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 657 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 656 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 44 "sequence/gcgl.l"
{ BEGIN HEAD; }
	YY_BREAK
case 2:
/* rule 2 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up gcgtext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up gcgtext again */
YY_RULE_SETUP
#line 45 "sequence/gcgl.l"
{ BEGIN SEQS; return TER; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 46 "sequence/gcgl.l"
{ return TXT; }
	YY_BREAK
case 4:
/* rule 4 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up gcgtext */
(yy_c_buf_p) = yy_cp -= 4;
YY_DO_BEFORE_ACTION; /* set up gcgtext again */
YY_RULE_SETUP
#line 47 "sequence/gcgl.l"
{ return TXT; }
	YY_BREAK
case 5:
/* rule 5 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up gcgtext */
(yy_c_buf_p) = yy_cp -= 3;
YY_DO_BEFORE_ACTION; /* set up gcgtext again */
YY_RULE_SETUP
#line 48 "sequence/gcgl.l"
{ return TXT; }
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 49 "sequence/gcgl.l"
{ return EOL; }
	YY_BREAK
case 7:
*yy_cp = (yy_hold_char); /* undo effects of setting up gcgtext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up gcgtext again */
YY_RULE_SETUP
#line 51 "sequence/gcgl.l"
; /* Leading spaces ignored */
	YY_BREAK
case 8:
/* rule 8 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up gcgtext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up gcgtext again */
YY_RULE_SETUP
#line 52 "sequence/gcgl.l"
; /* Trailing spaces ignored */
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 53 "sequence/gcgl.l"
{ yylval->str = strdup(gcgtext); return BAS; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 54 "sequence/gcgl.l"
{ return INT; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 55 "sequence/gcgl.l"
{ return SPC; }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 56 "sequence/gcgl.l"
; /* Empty sequence line ignored */
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 57 "sequence/gcgl.l"
{ return EOL; }
	YY_BREAK
case YY_STATE_EOF(SEQS):
#line 58 "sequence/gcgl.l"
{ init = 0; BEGIN INITIAL; return END; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 59 "sequence/gcgl.l"
{ return ERR; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(HEAD):
#line 61 "sequence/gcgl.l"
{ init = 0; BEGIN INITIAL; return NUL; }
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 62 "sequence/gcgl.l"
{ return ERR; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 63 "sequence/gcgl.l"
{ return ERR; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 65 "sequence/gcgl.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1435 "sequence/gcgl.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed gcgin at a new source and called
			 * gcglex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = gcgin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( gcgwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * gcgtext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of gcglex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					gcgrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			gcgrestart(gcgin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) gcgrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 657 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 657 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 656);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					gcgrestart(gcgin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( gcgwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve gcgtext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void gcgrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        gcgensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            gcg_create_buffer(gcgin,YY_BUF_SIZE );
	}

	gcg_init_buffer(YY_CURRENT_BUFFER,input_file );
	gcg_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void gcg_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		gcgpop_buffer_state();
	 *		gcgpush_buffer_state(new_buffer);
     */
	gcgensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	gcg_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (gcgwrap()) processing, but the only time this flag
	 * is looked at is after gcgwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void gcg_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	gcgin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE gcg_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) gcgalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in gcg_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) gcgalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in gcg_create_buffer()" );

	b->yy_is_our_buffer = 1;

	gcg_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with gcg_create_buffer()
 * 
 */
    void gcg_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		gcgfree((void *) b->yy_ch_buf  );

	gcgfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a gcgrestart() or at EOF.
 */
    static void gcg_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	gcg_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then gcg_init_buffer was _probably_
     * called from gcgrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void gcg_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		gcg_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void gcgpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	gcgensure_buffer_stack();

	/* This block is copied from gcg_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from gcg_switch_to_buffer. */
	gcg_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void gcgpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	gcg_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		gcg_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void gcgensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)gcgalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in gcgensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)gcgrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in gcgensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE gcg_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) gcgalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in gcg_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	gcg_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to gcglex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       gcg_scan_bytes() instead.
 */
YY_BUFFER_STATE gcg_scan_string (yyconst char * yystr )
{
    
	return gcg_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to gcglex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE gcg_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) gcgalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in gcg_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = gcg_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in gcg_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up gcgtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		gcgtext[gcgleng] = (yy_hold_char); \
		(yy_c_buf_p) = gcgtext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		gcgleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int gcgget_lineno  (void)
{
        
    return gcglineno;
}

/** Get the input stream.
 * 
 */
FILE *gcgget_in  (void)
{
        return gcgin;
}

/** Get the output stream.
 * 
 */
FILE *gcgget_out  (void)
{
        return gcgout;
}

/** Get the length of the current token.
 * 
 */
int gcgget_leng  (void)
{
        return gcgleng;
}

/** Get the current token.
 * 
 */

char *gcgget_text  (void)
{
        return gcgtext;
}

/** Set the current line number.
 * @param _line_number
 * 
 */
void gcgset_lineno (int  _line_number )
{
    
    gcglineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see gcg_switch_to_buffer
 */
void gcgset_in (FILE *  _in_str )
{
        gcgin = _in_str ;
}

void gcgset_out (FILE *  _out_str )
{
        gcgout = _out_str ;
}

int gcgget_debug  (void)
{
        return gcg_flex_debug;
}

void gcgset_debug (int  _bdebug )
{
        gcg_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from gcglex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    gcgin = stdin;
    gcgout = stdout;
#else
    gcgin = (FILE *) 0;
    gcgout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * gcglex_init()
     */
    return 0;
}

/* gcglex_destroy is for both reentrant and non-reentrant scanners. */
int gcglex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		gcg_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		gcgpop_buffer_state();
	}

	/* Destroy the stack itself. */
	gcgfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * gcglex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *gcgalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *gcgrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void gcgfree (void * ptr )
{
	free( (char *) ptr );	/* see gcgrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 65 "sequence/gcgl.l"



